==> haskell-neat-interpolation-0.5.1.4-191.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-LgltL8bGunlFCtvssaeg3T
key:                  neat-interpolation-0.5.1.4-LgltL8bGunlFCtvssaeg3T
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  5871d20c317b0a80157459e7b8c23d17
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-LgltL8bGunlFCtvssaeg3T
depends:
    base-4.18.2.1 megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.5.1.4-192-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 neat-interpolation
version:              0.5.1.4
visibility:           public
id:                   neat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
key:                  neat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
license:              MIT
copyright:            (c) 2013, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/neat-interpolation
synopsis:
    Quasiquoter for neat and simple multiline text interpolation

description:
    Quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.

category:             String, QuasiQuotes
abi:                  77324f507f1f43e3800b2ffd70b4bc00
exposed:              True
exposed-modules:      NeatInterpolation
hidden-modules:
    NeatInterpolation.Parsing NeatInterpolation.Prelude
    NeatInterpolation.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/neat-interpolation-0.5.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-neat-interpolation
hs-libraries:         HSneat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
depends:
    base-4.18.2.1 megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock

haddock-html:         /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
